### 介绍

利用Python实现搜索引擎中大批量关键词的搜索、导出与分析。

### 支持的python版本

Python 3

### 安装

- pip安装

  > pip install search

- 下载安装PypI官网（search-0.0.1tar.gz）

  > python setup.py install

### 浏览器&驱动下载

- Chrome浏览器
  - 下载浏览器
  - 帮助(E) > 关于Google Chrome(G) 查看Chrome浏览器版本号
- 驱动
  - 下载与Chrome浏览器版本一致的驱动 [链接1](https://sites.google.com/a/chromium.org/chromedriver/downloads) [链接2](http://npm.taobao.org/mirrors/chromedriver/) [链接3](https://chromedriver.storage.googleapis.com/index.html)

### 支持搜索引擎

- google.com

- baidu.com

- bing.com

- sogou.com
- weixin.sogou.com

### 使用

